#line 1 "source/parser/TextFileParser.rl"
#include "parser/TextFile.h"
#include "Color.h"
#include <string.h>
#include <stdlib.h>
#include <cstddef>
#include <functional>
#include <vector>
#include <string>
#include <iostream>
#include <cmath>
using namespace std;
namespace text_file_parser
{
	struct FSM
	{
		public:
		int cs;
		char separator;
		int act;
		int top;
		char *ts;
		char *te;
		int stack[256];
		char buffer[8 * 1024];
		int line;
		int column;
		int line_start;
		int buffer_offset;
		int64_t number_i64;
		vector<int64_t> numbers_i64;
		char *number_double_start;
		vector<double> numbers_double;
		function<void(const Color&)> addColor;
		void handleNewline()
		{
			line++;
			column = 0;
			line_start = te - buffer;
		}
		int hexToInt(char hex)
		{
			if (hex >= '0' && hex <= '9') return hex - '0';
				if (hex >= 'a' && hex <= 'f') return hex - 'a' + 10;
				if (hex >= 'A' && hex <= 'F') return hex - 'A' + 10;
				return 0;
		}
		int hexPairToInt(const char *hex_pair)
		{
			return hexToInt(hex_pair[0]) << 4 | hexToInt(hex_pair[1]);
		}
		void colorHexFull(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexPairToInt(ts + start_index) / 255.0f;
			color.rgb.green = hexPairToInt(ts + start_index + 2) / 255.0f;
			color.rgb.blue = hexPairToInt(ts + start_index + 4) / 255.0f;
			color[3] = 0;
			addColor(color);
		}
		void colorHexShort(bool with_hash_symbol)
		{
			Color color;
			int start_index = with_hash_symbol ? 1 : 0;
			color.rgb.red = hexToInt(ts[start_index + 0]) / 15.0f;
			color.rgb.green = hexToInt(ts[start_index + 1]) / 15.0f;
			color.rgb.blue = hexToInt(ts[start_index + 2]) / 15.0f;
			color[3] = 0;
			addColor(color);
		}
		void colorRgb()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0f;
			color.rgb.green = numbers_i64[1] / 255.0f;
			color.rgb.blue = numbers_i64[2] / 255.0f;
			color[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		void colorRgba()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0f;
			color.rgb.green = numbers_i64[1] / 255.0f;
			color.rgb.blue = numbers_i64[2] / 255.0f;
			color[3] = static_cast<float>(numbers_double[0]);
			numbers_i64.clear();
			numbers_double.clear();
			addColor(color);
		}
		void colorValues()
		{
			Color color;
			color.rgb.red = static_cast<float>(numbers_double[0]);
			color.rgb.green = static_cast<float>(numbers_double[1]);
			color.rgb.blue = static_cast<float>(numbers_double[2]);
			color[3] = 0;
			numbers_double.clear();
			addColor(color);
		}
		void colorValueIntegers()
		{
			Color color;
			color.rgb.red = numbers_i64[0] / 255.0f;
			color.rgb.green = numbers_i64[1] / 255.0f;
			color.rgb.blue = numbers_i64[2] / 255.0f;
			color[3] = 0;
			numbers_i64.clear();
			addColor(color);
		}
		double parseDouble(const char *start, const char *end)
		{
			string v(start, end);
			try {
				return stod(v.c_str());
			} catch(...) {
				return 0;
			}
		}
		void clearNumberStacks()
		{
			numbers_i64.clear();
			numbers_double.clear();
		}
	};
	
	
	
#line 162 "source/parser/TextFileParser.rl"

	

#line 133 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"
static const signed char _text_file_actions[] = {
		0, 1, 1, 1, 2, 1, 3, 1,
		4, 1, 5, 1, 6, 1, 7, 1,
		8, 1, 9, 1, 10, 1, 21, 1,
		22, 1, 23, 1, 24, 1, 25, 1,
		30, 1, 31, 1, 32, 1, 33, 1,
		34, 1, 35, 1, 36, 1, 37, 1,
		38, 2, 0, 1, 2, 2, 4, 2,
		2, 22, 2, 4, 23, 2, 4, 28,
		2, 4, 29, 2, 10, 11, 2, 10,
		12, 2, 10, 15, 2, 10, 16, 2,
		10, 17, 2, 10, 18, 2, 10, 19,
		2, 10, 20, 3, 0, 1, 3, 3,
		2, 4, 26, 3, 2, 4, 27, 3,
		10, 1, 13, 3, 10, 1, 14, 3,
		10, 1, 20, 3, 10, 3, 15, 3,
		10, 3, 16, 3, 10, 3, 19, 3,
		10, 11, 1, 3, 10, 12, 1, 5,
		10, 0, 1, 3, 20, 5, 10, 0,
		1, 13, 3, 5, 10, 0, 1, 14,
		3, 0
	};
	
	static const short _text_file_key_offsets[] = {
		0, 0, 6, 12, 18, 24, 32, 41,
		44, 46, 53, 61, 64, 66, 70, 72,
		76, 78, 83, 91, 99, 102, 104, 112,
		116, 124, 127, 129, 133, 135, 139, 141,
		147, 156, 160, 162, 168, 177, 179, 188,
		196, 205, 209, 217, 225, 233, 238, 244,
		248, 253, 259, 263, 268, 274, 278, 283,
		289, 293, 298, 304, 308, 313, 319, 323,
		331, 334, 336, 344, 348, 352, 354, 360,
		369, 371, 374, 375, 401, 411, 414, 418,
		426, 440, 446, 457, 467, 471, 473, 478,
		482, 484, 489, 499, 520, 525, 530, 551,
		572, 593, 614, 631, 645, 659, 675, 693,
		709, 727, 745, 761, 779, 797, 813, 831,
		849, 865, 877, 889, 902, 913, 913, 0
	};
	
	static const char _text_file_trans_keys[] = {
		48, 57, 65, 70, 97, 102, 48, 57,
		65, 70, 97, 102, 48, 57, 65, 70,
		97, 102, 48, 57, 65, 70, 97, 102,
		32, 44, 69, 101, 9, 13, 48, 57,
		32, 44, 46, 9, 13, 43, 45, 48,
		57, 46, 48, 57, 48, 57, 32, 69,
		101, 9, 13, 48, 57, 32, 43, 45,
		46, 9, 13, 48, 57, 46, 48, 57,
		48, 57, 43, 45, 48, 57, 48, 57,
		43, 45, 48, 57, 48, 57, 32, 9,
		13, 48, 57, 32, 46, 69, 101, 9,
		13, 48, 57, 32, 43, 45, 46, 9,
		13, 48, 57, 46, 48, 57, 48, 57,
		32, 44, 69, 101, 9, 13, 48, 57,
		32, 44, 9, 13, 32, 43, 45, 46,
		9, 13, 48, 57, 46, 48, 57, 48,
		57, 43, 45, 48, 57, 48, 57, 43,
		45, 48, 57, 48, 57, 32, 44, 9,
		13, 48, 57, 32, 44, 46, 69, 101,
		9, 13, 48, 57, 43, 45, 48, 57,
		48, 57, 32, 44, 9, 13, 48, 57,
		32, 44, 46, 69, 101, 9, 13, 48,
		57, 48, 57, 32, 44, 46, 9, 13,
		43, 45, 48, 57, 32, 43, 45, 46,
		9, 13, 48, 57, 32, 44, 46, 69,
		101, 9, 13, 48, 57, 32, 44, 9,
		13, 32, 43, 45, 46, 9, 13, 48,
		57, 32, 46, 69, 101, 9, 13, 48,
		57, 32, 43, 45, 46, 9, 13, 48,
		57, 32, 9, 13, 48, 57, 32, 44,
		9, 13, 48, 57, 32, 44, 9, 13,
		32, 9, 13, 48, 57, 32, 44, 9,
		13, 48, 57, 32, 44, 9, 13, 32,
		9, 13, 48, 57, 32, 41, 9, 13,
		48, 57, 32, 41, 9, 13, 32, 9,
		13, 48, 57, 32, 44, 9, 13, 48,
		57, 32, 44, 9, 13, 32, 9, 13,
		48, 57, 32, 44, 9, 13, 48, 57,
		32, 44, 9, 13, 32, 9, 13, 48,
		57, 32, 44, 9, 13, 48, 57, 32,
		44, 9, 13, 32, 43, 45, 46, 9,
		13, 48, 57, 46, 48, 57, 48, 57,
		32, 41, 69, 101, 9, 13, 48, 57,
		32, 41, 9, 13, 43, 45, 48, 57,
		48, 57, 32, 41, 9, 13, 48, 57,
		32, 41, 46, 69, 101, 9, 13, 48,
		57, 10, 42, 10, 42, 47, 10, 10,
		13, 32, 35, 43, 45, 46, 47, 82,
		114, 9, 12, 33, 44, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 9, 13, 32, 47, 58, 64, 91,
		96, 123, 126, 32, 9, 13, 10, 32,
		9, 13, 33, 47, 58, 64, 91, 96,
		123, 126, 33, 47, 48, 57, 58, 64,
		65, 70, 91, 96, 97, 102, 123, 126,
		48, 57, 65, 70, 97, 102, 46, 33,
		47, 48, 57, 58, 64, 91, 96, 123,
		126, 33, 47, 48, 57, 58, 64, 91,
		96, 123, 126, 69, 101, 48, 57, 48,
		57, 46, 69, 101, 48, 57, 69, 101,
		48, 57, 48, 57, 46, 69, 101, 48,
		57, 42, 47, 33, 46, 58, 64, 91,
		96, 123, 126, 32, 44, 46, 69, 101,
		9, 13, 33, 47, 48, 57, 58, 64,
		65, 70, 91, 96, 97, 102, 123, 126,
		46, 69, 101, 48, 57, 46, 69, 101,
		48, 57, 32, 44, 46, 69, 101, 9,
		13, 33, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 32,
		44, 46, 69, 101, 9, 13, 33, 47,
		48, 57, 58, 64, 65, 70, 91, 96,
		97, 102, 123, 126, 32, 44, 46, 69,
		101, 9, 13, 33, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 32, 44, 46, 69, 101, 9, 13,
		33, 47, 48, 57, 58, 64, 65, 70,
		91, 96, 97, 102, 123, 126, 32, 44,
		46, 69, 101, 9, 13, 33, 47, 48,
		57, 58, 64, 91, 96, 123, 126, 43,
		45, 9, 13, 32, 47, 48, 57, 58,
		64, 91, 96, 123, 126, 32, 44, 9,
		13, 33, 47, 48, 57, 58, 64, 91,
		96, 123, 126, 9, 13, 32, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 43, 45, 9, 13, 32,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 9, 13, 32,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 43, 45, 9,
		13, 32, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 32,
		44, 9, 13, 33, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 9, 13, 32, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 43, 45, 9, 13, 32, 47, 48,
		57, 58, 64, 65, 70, 91, 96, 97,
		102, 123, 126, 32, 44, 9, 13, 33,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 9, 13, 32,
		47, 48, 57, 58, 64, 65, 70, 91,
		96, 97, 102, 123, 126, 43, 45, 9,
		13, 32, 47, 48, 57, 58, 64, 65,
		70, 91, 96, 97, 102, 123, 126, 32,
		44, 9, 13, 33, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 9, 13, 32, 47, 48, 57, 58,
		64, 65, 70, 91, 96, 97, 102, 123,
		126, 71, 103, 9, 13, 32, 47, 58,
		64, 91, 96, 123, 126, 66, 98, 9,
		13, 32, 47, 58, 64, 91, 96, 123,
		126, 40, 65, 97, 9, 13, 32, 47,
		58, 64, 91, 96, 123, 126, 40, 9,
		13, 32, 47, 58, 64, 91, 96, 123,
		126, 0
	};
	
	static const signed char _text_file_single_lengths[] = {
		0, 0, 0, 0, 0, 4, 3, 1,
		0, 3, 4, 1, 0, 2, 0, 2,
		0, 1, 4, 4, 1, 0, 4, 2,
		4, 1, 0, 2, 0, 2, 0, 2,
		5, 2, 0, 2, 5, 0, 3, 4,
		5, 2, 4, 4, 4, 1, 2, 2,
		1, 2, 2, 1, 2, 2, 1, 2,
		2, 1, 2, 2, 1, 2, 2, 4,
		1, 0, 4, 2, 2, 0, 2, 5,
		2, 3, 1, 10, 0, 1, 2, 0,
		0, 0, 1, 0, 2, 0, 3, 2,
		0, 3, 2, 5, 3, 3, 5, 5,
		5, 5, 5, 2, 2, 0, 2, 0,
		2, 2, 0, 2, 2, 0, 2, 2,
		0, 2, 2, 3, 1, 0, 0, 0
	};
	
	static const signed char _text_file_range_lengths[] = {
		0, 3, 3, 3, 3, 2, 3, 1,
		1, 2, 2, 1, 1, 1, 1, 1,
		1, 2, 2, 2, 1, 1, 2, 1,
		2, 1, 1, 1, 1, 1, 1, 2,
		2, 1, 1, 2, 2, 1, 3, 2,
		2, 1, 2, 2, 2, 2, 2, 1,
		2, 2, 1, 2, 2, 1, 2, 2,
		1, 2, 2, 1, 2, 2, 1, 2,
		1, 1, 2, 1, 1, 1, 2, 2,
		0, 0, 0, 8, 5, 1, 1, 4,
		7, 3, 5, 5, 1, 1, 1, 1,
		1, 1, 4, 8, 1, 1, 8, 8,
		8, 8, 6, 6, 6, 8, 8, 8,
		8, 8, 8, 8, 8, 8, 8, 8,
		8, 5, 5, 5, 5, 0, 0, 0
	};
	
	static const short _text_file_index_offsets[] = {
		0, 0, 4, 8, 12, 16, 23, 30,
		33, 35, 41, 48, 51, 53, 57, 59,
		63, 65, 69, 76, 83, 86, 88, 95,
		99, 106, 109, 111, 115, 117, 121, 123,
		128, 136, 140, 142, 147, 155, 157, 164,
		171, 179, 183, 190, 197, 204, 208, 213,
		217, 221, 226, 230, 234, 239, 243, 247,
		252, 256, 260, 265, 269, 273, 278, 282,
		289, 292, 294, 301, 305, 309, 311, 316,
		324, 327, 331, 333, 352, 358, 361, 365,
		370, 378, 382, 389, 395, 399, 401, 406,
		410, 412, 417, 424, 438, 443, 448, 462,
		476, 490, 504, 516, 525, 534, 543, 554,
		563, 574, 585, 594, 605, 616, 625, 636,
		647, 656, 664, 672, 681, 688, 689, 0
	};
	
	static const signed char _text_file_cond_targs[] = {
		2, 2, 2, 75, 81, 81, 81, 75,
		4, 4, 4, 75, 75, 75, 75, 75,
		6, 19, 33, 33, 6, 5, 75, 6,
		19, 8, 6, 7, 18, 75, 8, 18,
		75, 9, 75, 10, 15, 15, 10, 9,
		75, 10, 11, 11, 12, 10, 86, 75,
		12, 86, 75, 84, 75, 14, 14, 85,
		75, 85, 75, 16, 16, 17, 75, 17,
		75, 10, 10, 17, 75, 10, 8, 15,
		15, 10, 18, 75, 19, 20, 20, 21,
		19, 32, 75, 21, 32, 75, 22, 75,
		23, 24, 29, 29, 23, 22, 75, 23,
		24, 23, 75, 24, 25, 25, 26, 24,
		89, 75, 26, 89, 75, 87, 75, 28,
		28, 88, 75, 88, 75, 30, 30, 31,
		75, 31, 75, 23, 24, 23, 31, 75,
		23, 24, 21, 29, 29, 23, 32, 75,
		34, 34, 35, 75, 35, 75, 6, 19,
		6, 35, 75, 6, 19, 37, 33, 33,
		6, 36, 75, 5, 75, 38, 39, 8,
		38, 7, 43, 75, 39, 20, 20, 21,
		39, 40, 75, 41, 42, 21, 29, 29,
		41, 40, 75, 41, 42, 41, 75, 42,
		25, 25, 26, 42, 92, 75, 44, 8,
		15, 15, 44, 43, 75, 44, 11, 11,
		12, 44, 93, 75, 45, 45, 46, 75,
		47, 48, 47, 46, 75, 47, 48, 47,
		75, 48, 48, 49, 75, 50, 51, 50,
		49, 75, 50, 51, 50, 75, 51, 51,
		52, 75, 53, 75, 53, 52, 75, 53,
		75, 53, 75, 54, 54, 55, 75, 56,
		57, 56, 55, 75, 56, 57, 56, 75,
		57, 57, 58, 75, 59, 60, 59, 58,
		75, 59, 60, 59, 75, 60, 60, 61,
		75, 62, 63, 62, 61, 75, 62, 63,
		62, 75, 63, 64, 64, 65, 63, 71,
		75, 65, 71, 75, 66, 75, 67, 75,
		68, 68, 67, 66, 75, 67, 75, 67,
		75, 69, 69, 70, 75, 70, 75, 67,
		75, 67, 70, 75, 67, 75, 65, 68,
		68, 67, 71, 75, 72, 73, 72, 72,
		73, 117, 72, 118, 74, 77, 78, 77,
		80, 82, 82, 83, 90, 113, 113, 77,
		79, 91, 79, 112, 79, 112, 79, 76,
		75, 75, 75, 75, 75, 76, 77, 77,
		75, 77, 77, 77, 75, 79, 79, 79,
		79, 75, 79, 1, 79, 1, 79, 1,
		79, 75, 3, 3, 3, 75, 83, 79,
		36, 79, 79, 79, 75, 79, 5, 79,
		79, 79, 75, 13, 13, 84, 75, 85,
		75, 12, 13, 13, 86, 75, 27, 27,
		87, 75, 88, 75, 26, 27, 27, 89,
		75, 79, 79, 79, 79, 79, 79, 75,
		38, 39, 37, 110, 110, 38, 75, 94,
		75, 109, 75, 109, 75, 76, 26, 27,
		27, 92, 75, 12, 13, 13, 93, 75,
		38, 39, 37, 107, 107, 38, 75, 95,
		75, 106, 75, 106, 75, 76, 38, 39,
		37, 104, 104, 38, 75, 96, 75, 103,
		75, 103, 75, 76, 38, 39, 37, 102,
		102, 38, 75, 97, 75, 101, 75, 101,
		75, 76, 38, 39, 37, 99, 99, 38,
		75, 98, 75, 76, 75, 76, 75, 76,
		38, 39, 37, 99, 99, 38, 75, 98,
		75, 75, 75, 76, 34, 34, 75, 75,
		100, 75, 75, 75, 76, 6, 19, 6,
		75, 100, 75, 75, 75, 76, 75, 75,
		76, 75, 76, 75, 76, 75, 76, 34,
		34, 75, 75, 100, 75, 76, 75, 76,
		75, 76, 75, 75, 101, 75, 101, 75,
		101, 75, 76, 34, 34, 75, 75, 105,
		75, 101, 75, 101, 75, 76, 6, 19,
		6, 75, 100, 75, 76, 75, 76, 75,
		76, 75, 75, 103, 75, 103, 75, 103,
		75, 76, 34, 34, 75, 75, 108, 75,
		103, 75, 103, 75, 76, 6, 19, 6,
		75, 105, 75, 101, 75, 101, 75, 76,
		75, 75, 106, 75, 106, 75, 106, 75,
		76, 34, 34, 75, 75, 111, 75, 106,
		75, 106, 75, 76, 6, 19, 6, 75,
		108, 75, 103, 75, 103, 75, 76, 75,
		75, 109, 75, 109, 75, 109, 75, 76,
		114, 114, 75, 75, 75, 75, 75, 76,
		115, 115, 75, 75, 75, 75, 75, 76,
		45, 116, 116, 75, 75, 75, 75, 75,
		76, 54, 75, 75, 75, 75, 75, 76,
		0, 0, 0, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 72, 73, 74, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 75,
		75, 75, 75, 75, 75, 75, 75, 117,
		118, 0
	};
	
	static const short _text_file_cond_actions[] = {
		0, 0, 0, 41, 19, 19, 19, 41,
		0, 0, 0, 39, 21, 21, 21, 39,
		7, 7, 0, 0, 7, 0, 47, 0,
		0, 5, 0, 5, 5, 47, 0, 0,
		47, 0, 47, 7, 0, 0, 7, 0,
		47, 0, 5, 5, 5, 0, 119, 47,
		0, 76, 47, 76, 47, 0, 0, 0,
		47, 0, 47, 0, 0, 0, 47, 0,
		47, 7, 7, 0, 47, 7, 0, 0,
		0, 7, 0, 47, 0, 5, 5, 5,
		0, 5, 47, 0, 0, 47, 0, 47,
		7, 7, 0, 0, 7, 0, 47, 0,
		0, 0, 47, 0, 5, 5, 5, 0,
		115, 47, 0, 73, 47, 73, 47, 0,
		0, 0, 47, 0, 47, 0, 0, 0,
		47, 0, 47, 7, 7, 7, 0, 47,
		7, 7, 0, 0, 0, 7, 0, 47,
		0, 0, 0, 47, 0, 47, 7, 7,
		7, 0, 47, 7, 7, 0, 0, 0,
		7, 0, 43, 0, 47, 0, 0, 5,
		0, 5, 91, 47, 0, 5, 5, 5,
		0, 91, 47, 52, 52, 0, 0, 0,
		52, 1, 47, 0, 0, 0, 47, 0,
		5, 5, 5, 0, 141, 47, 52, 0,
		0, 0, 52, 1, 47, 0, 5, 5,
		5, 0, 147, 47, 0, 0, 49, 45,
		3, 3, 3, 1, 45, 0, 0, 0,
		45, 0, 0, 49, 45, 3, 3, 3,
		1, 45, 0, 0, 0, 45, 0, 0,
		49, 45, 3, 55, 3, 1, 45, 0,
		23, 0, 45, 0, 0, 49, 45, 3,
		3, 3, 1, 45, 0, 0, 0, 45,
		0, 0, 49, 45, 3, 3, 3, 1,
		45, 0, 0, 0, 45, 0, 0, 49,
		45, 3, 3, 3, 1, 45, 0, 0,
		0, 45, 0, 5, 5, 5, 0, 5,
		45, 0, 0, 45, 0, 45, 7, 58,
		0, 0, 7, 0, 45, 0, 25, 0,
		45, 0, 0, 0, 45, 0, 45, 7,
		58, 7, 0, 45, 7, 58, 0, 0,
		0, 7, 0, 45, 9, 0, 0, 9,
		0, 11, 0, 13, 0, 9, 0, 0,
		19, 123, 123, 123, 0, 0, 0, 0,
		85, 135, 85, 0, 85, 0, 85, 88,
		47, 47, 47, 47, 47, 88, 0, 0,
		33, 9, 0, 0, 33, 85, 85, 85,
		85, 47, 85, 0, 85, 0, 85, 0,
		85, 31, 0, 0, 0, 27, 85, 85,
		0, 85, 85, 85, 35, 85, 0, 85,
		85, 85, 35, 0, 0, 76, 64, 0,
		64, 0, 0, 0, 76, 64, 0, 0,
		73, 61, 0, 61, 0, 0, 0, 73,
		61, 82, 79, 85, 85, 85, 85, 35,
		52, 52, 0, 88, 88, 52, 37, 111,
		37, 0, 37, 0, 37, 88, 3, 3,
		3, 103, 95, 3, 3, 3, 107, 99,
		52, 52, 0, 70, 70, 52, 37, 131,
		37, 0, 37, 0, 37, 88, 52, 52,
		0, 88, 88, 52, 29, 111, 29, 0,
		29, 0, 29, 88, 52, 52, 0, 88,
		88, 52, 37, 111, 37, 0, 37, 0,
		37, 88, 52, 52, 0, 67, 67, 52,
		37, 127, 37, 67, 37, 67, 37, 88,
		52, 52, 0, 88, 88, 52, 47, 111,
		47, 47, 47, 88, 0, 0, 47, 47,
		88, 47, 47, 47, 88, 7, 7, 7,
		47, 88, 47, 47, 47, 88, 37, 37,
		67, 37, 67, 37, 67, 37, 88, 0,
		0, 37, 37, 67, 37, 67, 37, 67,
		37, 88, 37, 37, 0, 37, 0, 37,
		0, 37, 88, 0, 0, 37, 37, 88,
		37, 0, 37, 0, 37, 88, 7, 7,
		7, 37, 67, 37, 67, 37, 67, 37,
		88, 29, 29, 0, 29, 0, 29, 0,
		29, 88, 0, 0, 29, 29, 88, 29,
		0, 29, 0, 29, 88, 7, 7, 7,
		37, 88, 37, 0, 37, 0, 37, 88,
		37, 37, 0, 37, 0, 37, 0, 37,
		88, 0, 0, 37, 37, 70, 37, 0,
		37, 0, 37, 88, 7, 7, 7, 29,
		88, 29, 0, 29, 0, 29, 88, 37,
		37, 0, 37, 0, 37, 0, 37, 88,
		0, 0, 37, 37, 37, 37, 37, 88,
		19, 19, 37, 37, 37, 37, 37, 88,
		0, 19, 19, 37, 37, 37, 37, 37,
		88, 0, 37, 37, 37, 37, 37, 88,
		0, 0, 0, 41, 41, 39, 39, 47,
		47, 47, 47, 47, 47, 47, 47, 47,
		47, 47, 47, 47, 47, 47, 47, 47,
		47, 47, 47, 47, 47, 47, 47, 47,
		47, 47, 47, 47, 47, 47, 43, 47,
		47, 47, 47, 47, 47, 47, 47, 45,
		45, 45, 45, 45, 45, 45, 45, 45,
		45, 45, 45, 45, 45, 45, 45, 45,
		45, 45, 45, 45, 45, 45, 45, 45,
		45, 45, 0, 0, 0, 0, 47, 33,
		33, 47, 31, 27, 35, 35, 64, 64,
		64, 61, 61, 61, 35, 37, 95, 99,
		37, 29, 37, 37, 47, 47, 47, 37,
		37, 37, 37, 37, 29, 29, 37, 37,
		37, 29, 37, 37, 37, 37, 37, 0,
		0, 0
	};
	
	static const signed char _text_file_to_state_actions[] = {
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		15, 0, 15, 15, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0
	};
	
	static const signed char _text_file_from_state_actions[] = {
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 17, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0,
		0, 0, 0, 0, 0, 0, 0, 0
	};
	
	static const short _text_file_eof_trans[] = {
		691, 692, 693, 694, 695, 696, 697, 698,
		699, 700, 701, 702, 703, 704, 705, 706,
		707, 708, 709, 710, 711, 712, 713, 714,
		715, 716, 717, 718, 719, 720, 721, 722,
		723, 724, 725, 726, 727, 728, 729, 730,
		731, 732, 733, 734, 735, 736, 737, 738,
		739, 740, 741, 742, 743, 744, 745, 746,
		747, 748, 749, 750, 751, 752, 753, 754,
		755, 756, 757, 758, 759, 760, 761, 762,
		763, 764, 765, 766, 767, 768, 769, 770,
		771, 772, 773, 774, 775, 776, 777, 778,
		779, 780, 781, 782, 783, 784, 785, 786,
		787, 788, 789, 790, 791, 792, 793, 794,
		795, 796, 797, 798, 799, 800, 801, 802,
		803, 804, 805, 806, 807, 808, 809, 0
	};
	
	static const int text_file_start = 75;
	static const int text_file_first_final = 75;
	static const int text_file_error = 0;
	
	static const int text_file_en_multi_line_comment = 72;
	static const int text_file_en_single_line_comment = 74;
	static const int text_file_en_main = 75;
	
	
#line 164 "source/parser/TextFileParser.rl"

	
	bool scanner(TextFile &text_file, const Configuration &configuration)
	{
		FSM fsm_struct;
		FSM *fsm = &fsm_struct;
		fsm->ts = 0;
		fsm->te = 0;
		fsm->line = 0;
		fsm->line_start = 0;
		fsm->column = 0;
		fsm->buffer_offset = 0;
		bool parse_error = false;
		fsm->addColor = [&text_file](const Color &color){
			text_file.addColor(color.normalizeRgb());
		};

#line 635 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"
	{
			fsm->cs = (int)text_file_start;
			fsm->ts = 0;
			fsm->te = 0;
			fsm->act = 0;
		}
		
#line 180 "source/parser/TextFileParser.rl"

		int have = 0;
		while (1){
			char *p = fsm->buffer + have;
			int space = sizeof(fsm->buffer) - have;
			if (space == 0){
				text_file.outOfMemory();
				break;
			}
			char *eof = 0;
			auto read_size = text_file.read(fsm->buffer + have, space);
			char *pe = p + read_size;
			if (read_size > 0){
				if (read_size < sizeof(fsm->buffer)) eof = pe;

#line 656 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"
	{
					int _klen;
					unsigned int _trans = 0;
					const char * _keys;
					const signed char * _acts;
					unsigned int _nacts;
					_resume: {}
					if ( p == pe && p != eof )
						goto _out;
					_acts = ( _text_file_actions + (_text_file_from_state_actions[fsm->cs]));
					_nacts = (unsigned int)(*( _acts));
					_acts += 1;
					while ( _nacts > 0 ) {
						switch ( (*( _acts)) ) {
							case 9:  {
									{
#line 1 "NONE"
									{fsm->ts = p;}}
								
#line 675 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

								break; 
							}
						}
						_nacts -= 1;
						_acts += 1;
					}
					
					if ( p == eof ) {
						if ( _text_file_eof_trans[fsm->cs] > 0 ) {
							_trans = (unsigned int)_text_file_eof_trans[fsm->cs] - 1;
						}
					}
					else {
						_keys = ( _text_file_trans_keys + (_text_file_key_offsets[fsm->cs]));
						_trans = (unsigned int)_text_file_index_offsets[fsm->cs];
						
						_klen = (int)_text_file_single_lengths[fsm->cs];
						if ( _klen > 0 ) {
							const char *_lower = _keys;
							const char *_upper = _keys + _klen - 1;
							const char *_mid;
							while ( 1 ) {
								if ( _upper < _lower ) {
									_keys += _klen;
									_trans += (unsigned int)_klen;
									break;
								}
								
								_mid = _lower + ((_upper-_lower) >> 1);
								if ( ( (*( p))) < (*( _mid)) )
									_upper = _mid - 1;
								else if ( ( (*( p))) > (*( _mid)) )
									_lower = _mid + 1;
								else {
									_trans += (unsigned int)(_mid - _keys);
									goto _match;
								}
							}
						}
						
						_klen = (int)_text_file_range_lengths[fsm->cs];
						if ( _klen > 0 ) {
							const char *_lower = _keys;
							const char *_upper = _keys + (_klen<<1) - 2;
							const char *_mid;
							while ( 1 ) {
								if ( _upper < _lower ) {
									_trans += (unsigned int)_klen;
									break;
								}
								
								_mid = _lower + (((_upper-_lower) >> 1) & ~1);
								if ( ( (*( p))) < (*( _mid)) )
									_upper = _mid - 2;
								else if ( ( (*( p))) > (*( _mid + 1)) )
									_lower = _mid + 2;
								else {
									_trans += (unsigned int)((_mid - _keys)>>1);
									break;
								}
							}
						}
						
						_match: {}
					}
					fsm->cs = (int)_text_file_cond_targs[_trans];
					
					if ( _text_file_cond_actions[_trans] != 0 ) {
						
						_acts = ( _text_file_actions + (_text_file_cond_actions[_trans]));
						_nacts = (unsigned int)(*( _acts));
						_acts += 1;
						while ( _nacts > 0 ) {
							switch ( (*( _acts)) )
							{
								case 0:  {
										{
#line 132 "source/parser/TextFileParser.rl"
										fsm->number_i64 = 0; }
									
#line 756 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 1:  {
										{
#line 132 "source/parser/TextFileParser.rl"
										fsm->number_i64 = fsm->number_i64 * 10 + (*p - '0'); }
									
#line 764 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 2:  {
										{
#line 135 "source/parser/TextFileParser.rl"
										fsm->numbers_i64.push_back(fsm->number_i64); }
									
#line 772 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 3:  {
										{
#line 136 "source/parser/TextFileParser.rl"
										fsm->number_double_start = p; }
									
#line 780 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 4:  {
										{
#line 136 "source/parser/TextFileParser.rl"
										fsm->numbers_double.push_back(fsm->parseDouble(fsm->number_double_start, p)); }
									
#line 788 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 5:  {
										{
#line 138 "source/parser/TextFileParser.rl"
										fsm->handleNewline(); }
									
#line 796 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 6:  {
										{
#line 140 "source/parser/TextFileParser.rl"
										{fsm->cs = 75;goto _again;}}
									
#line 804 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 7:  {
										{
#line 141 "source/parser/TextFileParser.rl"
										{fsm->cs = 75;goto _again;}}
									
#line 812 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 10:  {
										{
#line 1 "NONE"
										{fsm->te = p+1;}}
									
#line 820 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 11:  {
										{
#line 146 "source/parser/TextFileParser.rl"
										{fsm->act = 3;}}
									
#line 828 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 12:  {
										{
#line 147 "source/parser/TextFileParser.rl"
										{fsm->act = 4;}}
									
#line 836 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 13:  {
										{
#line 150 "source/parser/TextFileParser.rl"
										{fsm->act = 7;}}
									
#line 844 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 14:  {
										{
#line 151 "source/parser/TextFileParser.rl"
										{fsm->act = 8;}}
									
#line 852 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 15:  {
										{
#line 152 "source/parser/TextFileParser.rl"
										{fsm->act = 9;}}
									
#line 860 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 16:  {
										{
#line 153 "source/parser/TextFileParser.rl"
										{fsm->act = 10;}}
									
#line 868 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 17:  {
										{
#line 154 "source/parser/TextFileParser.rl"
										{fsm->act = 11;}}
									
#line 876 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 18:  {
										{
#line 155 "source/parser/TextFileParser.rl"
										{fsm->act = 12;}}
									
#line 884 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 19:  {
										{
#line 158 "source/parser/TextFileParser.rl"
										{fsm->act = 15;}}
									
#line 892 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 20:  {
										{
#line 159 "source/parser/TextFileParser.rl"
										{fsm->act = 16;}}
									
#line 900 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 21:  {
										{
#line 144 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 144 "source/parser/TextFileParser.rl"
												if (configuration.full_hex) fsm->colorHexFull(true); }
										}}
									
#line 911 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 22:  {
										{
#line 148 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 148 "source/parser/TextFileParser.rl"
												if (configuration.css_rgb) fsm->colorRgb(); else fsm->clearNumberStacks(); }
										}}
									
#line 922 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 23:  {
										{
#line 149 "source/parser/TextFileParser.rl"
										{fsm->te = p+1;{
#line 149 "source/parser/TextFileParser.rl"
												if (configuration.css_rgba) fsm->colorRgba(); else fsm->clearNumberStacks(); }
										}}
									
#line 933 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 24:  {
										{
#line 145 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 145 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(true); }
										}}
									
#line 944 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 25:  {
										{
#line 147 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 147 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(false); }
										}}
									
#line 955 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 26:  {
										{
#line 150 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 150 "source/parser/TextFileParser.rl"
												if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
										}}
									
#line 966 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 27:  {
										{
#line 151 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 151 "source/parser/TextFileParser.rl"
												if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
										}}
									
#line 977 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 28:  {
										{
#line 152 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 152 "source/parser/TextFileParser.rl"
												if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
										}}
									
#line 988 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 29:  {
										{
#line 153 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 153 "source/parser/TextFileParser.rl"
												if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
										}}
									
#line 999 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 30:  {
										{
#line 156 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 156 "source/parser/TextFileParser.rl"
												if (configuration.single_line_hash_comments) {fsm->cs = 74;goto _again;}}
										}}
									
#line 1010 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 31:  {
										{
#line 157 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 157 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1021 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 32:  {
										{
#line 158 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 158 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1032 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 33:  {
										{
#line 159 "source/parser/TextFileParser.rl"
										{fsm->te = p;p = p - 1;{
#line 159 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1043 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 34:  {
										{
#line 145 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 145 "source/parser/TextFileParser.rl"
												if (configuration.short_hex) fsm->colorHexShort(true); }
										}}
									
#line 1055 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 35:  {
										{
#line 156 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 156 "source/parser/TextFileParser.rl"
												if (configuration.single_line_hash_comments) {fsm->cs = 74;goto _again;}}
										}}
									
#line 1067 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 36:  {
										{
#line 158 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 158 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1079 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 37:  {
										{
#line 159 "source/parser/TextFileParser.rl"
										{p = ((fsm->te))-1;
											{
#line 159 "source/parser/TextFileParser.rl"
											}
										}}
									
#line 1091 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
								case 38:  {
										{
#line 1 "NONE"
										{switch( fsm->act ) {
												case 3:  {
													p = ((fsm->te))-1;
													{
#line 146 "source/parser/TextFileParser.rl"
														if (configuration.full_hex) fsm->colorHexFull(false); }
													break; 
												}
												case 4:  {
													p = ((fsm->te))-1;
													{
#line 147 "source/parser/TextFileParser.rl"
														if (configuration.short_hex) fsm->colorHexShort(false); }
													break; 
												}
												case 7:  {
													p = ((fsm->te))-1;
													{
#line 150 "source/parser/TextFileParser.rl"
														if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 8:  {
													p = ((fsm->te))-1;
													{
#line 151 "source/parser/TextFileParser.rl"
														if (configuration.int_values) fsm->colorValueIntegers(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 9:  {
													p = ((fsm->te))-1;
													{
#line 152 "source/parser/TextFileParser.rl"
														if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 10:  {
													p = ((fsm->te))-1;
													{
#line 153 "source/parser/TextFileParser.rl"
														if (configuration.float_values) fsm->colorValues(); else fsm->clearNumberStacks(); }
													break; 
												}
												case 11:  {
													p = ((fsm->te))-1;
													{
#line 154 "source/parser/TextFileParser.rl"
														if (configuration.single_line_c_comments) {fsm->cs = 74;goto _again;}}
													break; 
												}
												case 12:  {
													p = ((fsm->te))-1;
													{
#line 155 "source/parser/TextFileParser.rl"
														if (configuration.multi_line_c_comments) {fsm->cs = 72;goto _again;}}
													break; 
												}
												case 15:  {
													p = ((fsm->te))-1;
													{
#line 158 "source/parser/TextFileParser.rl"
													}
													break; 
												}
												case 16:  {
													p = ((fsm->te))-1;
													{
#line 159 "source/parser/TextFileParser.rl"
													}
													break; 
												}
											}}
									}
									
#line 1171 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
							}
							_nacts -= 1;
							_acts += 1;
						}
						
					}
					
					_again: {}
					if ( p == eof ) {
						if ( fsm->cs >= 75 )
							goto _out;
					}
					else {
						_acts = ( _text_file_actions + (_text_file_to_state_actions[fsm->cs]));
						_nacts = (unsigned int)(*( _acts));
						_acts += 1;
						while ( _nacts > 0 ) {
							switch ( (*( _acts)) ) {
								case 8:  {
										{
#line 1 "NONE"
										{fsm->ts = 0;}}
									
#line 1197 "/builddir/build/BUILD/gpick-0e858d33fd28d98d2689d0ebb92c975729a9f7bc/redhat-linux-build/CMakeFiles/TextFileParser.cpp"

									break; 
								}
							}
							_nacts -= 1;
							_acts += 1;
						}
						
						if ( fsm->cs != 0 ) {
							p += 1;
							goto _resume;
						}
					}
					_out: {}
				}
				
#line 194 "source/parser/TextFileParser.rl"

				if (fsm->cs == text_file_error) {
					parse_error = true;
					text_file.syntaxError(fsm->line, fsm->ts - fsm->buffer - fsm->line_start, fsm->line, fsm->te - fsm->buffer - fsm->line_start);
					break;
				}
				if (fsm->ts == 0){
					have = 0;
					fsm->line_start -= sizeof(fsm->buffer);
				}else{
					have = pe - fsm->ts;
					memmove(fsm->buffer, fsm->ts, have);
					int buffer_movement = fsm->ts - fsm->buffer;
					fsm->te -= buffer_movement;
					fsm->line_start -= buffer_movement;
					fsm->ts = fsm->buffer;
					fsm->buffer_offset += fsm->ts - fsm->buffer;
				}
			}else{
				break;
			}
		}
		return parse_error == false;
	}
	
}
